==> mktcenter-service-1.5.3-vg-20221108.085411-15-sources.jar: com/bizvane/mktcenterservice/models/vo/TaskSearchVO.java <==
package com.bizvane.mktcenterservice.models.vo;

import java.util.Date;

/**
 * @Author: lijunwei
 * @Time: 2018/10/26 14:12
 */
public class TaskSearchVO {
    private String  taskCode;
    private String taskName;
    private Integer checkStatus;
    private Integer taskStatus;
    private Date startTime;
    private Date endTime;
    private Integer taskType;
    private Long brandId;
    private Integer pageNumber=1;
    private Integer pageSize=10;
    private String  organizationCode;
    private String createUserName;
    private String memberTouristName;

    public String getMemberTouristName() {
        return memberTouristName;
    }

    public void setMemberTouristName(String memberTouristName) {
        this.memberTouristName = memberTouristName;
    }

    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getTaskType() {
        return taskType;
    }

    public void setTaskType(Integer taskType) {
        this.taskType = taskType;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public Integer getPageNumber() {
        return pageNumber;
    }

    public void setPageNumber(Integer pageNumber) {
        this.pageNumber = pageNumber;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getTaskStatus() {
        return taskStatus;
    }

    public void setTaskStatus(Integer taskStatus) {
        this.taskStatus = taskStatus;
    }

    public String getOrganizationCode() {
        return organizationCode;
    }

    public void setOrganizationCode(String organizationCode) {
        this.organizationCode = organizationCode;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
}

==> mktcenter-service-1.5.6-vg-20230128.080549-4-sources.jar: com/bizvane/mktcenterservice/models/vo/TaskSearchVO.java <==
package com.bizvane.mktcenterservice.models.vo;

import java.util.Date;

/**
 * @Author: lijunwei
 * @Time: 2018/10/26 14:12
 */
public class TaskSearchVO {
    private Long taskId;
    private String  taskCode;
    private String taskName;
    private Integer checkStatus;
    private Integer taskStatus;
    private Date startTime;
    private Date endTime;
    private Integer taskType;
    private Long brandId;
    private Integer pageNumber=1;
    private Integer pageSize=10;
    private String  organizationCode;
    private String createUserName;
    private String memberTouristName;

    private String memberTemplateName;

    private String touristMemberTemplateName;

    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getTaskType() {
        return taskType;
    }

    public void setTaskType(Integer taskType) {
        this.taskType = taskType;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public Integer getPageNumber() {
        return pageNumber;
    }

    public void setPageNumber(Integer pageNumber) {
        this.pageNumber = pageNumber;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getTaskStatus() {
        return taskStatus;
    }

    public void setTaskStatus(Integer taskStatus) {
        this.taskStatus = taskStatus;
    }

    public String getOrganizationCode() {
        return organizationCode;
    }

    public void setOrganizationCode(String organizationCode) {
        this.organizationCode = organizationCode;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }


    public String getMemberTemplateName() {
        return memberTemplateName;
    }

    public void setMemberTemplateName(String memberTemplateName) {
        this.memberTemplateName = memberTemplateName;
    }

    public String getTouristMemberTemplateName() {
        return touristMemberTemplateName;
    }

    public void setTouristMemberTemplateName(String touristMemberTemplateName) {
        this.touristMemberTemplateName = touristMemberTemplateName;
    }

    public Long getTaskId() {
        return taskId;
    }

    public void setTaskId(Long taskId) {
        this.taskId = taskId;
    }

    public String getMemberTouristName() {
        return memberTouristName;
    }

    public void setMemberTouristName(String memberTouristName) {
        this.memberTouristName = memberTouristName;
    }

}
